<?php

namespace Litecms\FaqsCategories\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\FaqsCategories\Models\Faqcategories;

class FaqcategoriesPolicy
{

    /**
     * Determine if the given user can view the faqcategories.
     *
     * @param UserPolicy $user
     * @param Faqcategories $faqcategories
     *
     * @return bool
     */
    public function view(UserPolicy $user, Faqcategories $faqcategories)
    {
        if ($user->canDo('faqs_categories.faqcategories.view') && $user->isAdmin()) {
            return true;
        }

        return $faqcategories->user_id == user_id() && $faqcategories->user_type == user_type();
    }

    /**
     * Determine if the given user can create a faqcategories.
     *
     * @param UserPolicy $user
     * @param Faqcategories $faqcategories
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('faqs_categories.faqcategories.create');
    }

    /**
     * Determine if the given user can update the given faqcategories.
     *
     * @param UserPolicy $user
     * @param Faqcategories $faqcategories
     *
     * @return bool
     */
    public function update(UserPolicy $user, Faqcategories $faqcategories)
    {
        if ($user->canDo('faqs_categories.faqcategories.edit') && $user->isAdmin()) {
            return true;
        }

        return $faqcategories->user_id == user_id() && $faqcategories->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given faqcategories.
     *
     * @param UserPolicy $user
     * @param Faqcategories $faqcategories
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Faqcategories $faqcategories)
    {
        return $faqcategories->user_id == user_id() && $faqcategories->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given faqcategories.
     *
     * @param UserPolicy $user
     * @param Faqcategories $faqcategories
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Faqcategories $faqcategories)
    {
        if ($user->canDo('faqs_categories.faqcategories.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given faqcategories.
     *
     * @param UserPolicy $user
     * @param Faqcategories $faqcategories
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Faqcategories $faqcategories)
    {
        if ($user->canDo('faqs_categories.faqcategories.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
