<?php

namespace Litecms\FaqsCategories\Providers;

use Illuminate\Support\ServiceProvider;

class FaqsCategoriesServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'faqs_categories');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'faqs_categories');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.faqs_categories', function ($app) {
            return $this->app->make('Litecms\FaqsCategories\FaqsCategories');
        });

                // Bind Faqcategories to repository
        $this->app->bind(
            'Litecms\FaqsCategories\Interfaces\FaqcategoriesRepositoryInterface',
            \Litecms\FaqsCategories\Repositories\Eloquent\FaqcategoriesRepository::class
        );

        $this->app->register(\Litecms\FaqsCategories\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\FaqsCategories\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.faqs_categories'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/faqs_categories.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/faqs_categories')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/faqs_categories')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
